@@ -1,6 +1,8 @@
-.onLoad <- function(libname = find.package("fSRM"), pkgname = "fSRM") {	
-	
-}
+#' @importFrom grDevices gray
+#' @importFrom methods show
+#' @importFrom stats addmargins formula pchisq
+#' @importFrom utils packageDescription packageVersion read.csv read.table str
+
 
 # Define skinning variables in a new environment
 #------------------------------------
